@@ -74,7 +74,7 @@ enum css_properties_e {
 	CSS_PROP_OUTLINE_COLOR			= 0x039,
 	CSS_PROP_OUTLINE_STYLE			= 0x03a,
 	CSS_PROP_OUTLINE_WIDTH			= 0x03b,
-	CSS_PROP_OVERFLOW			= 0x03c,
+	CSS_PROP_OVERFLOW_X			= 0x03c,
 	CSS_PROP_PADDING_TOP			= 0x03d,
 	CSS_PROP_PADDING_RIGHT			= 0x03e,
 	CSS_PROP_PADDING_BOTTOM			= 0x03f,
@@ -126,10 +126,51 @@ enum css_properties_e {
 	CSS_PROP_COLUMN_SPAN			= 0x06d,
 	CSS_PROP_COLUMN_WIDTH			= 0x06e,
 	CSS_PROP_WRITING_MODE			= 0x06f,
+	CSS_PROP_OVERFLOW_Y			= 0x070,
+	CSS_PROP_BOX_SIZING			= 0x071,
+	CSS_PROP_ALIGN_CONTENT			= 0x072,
+	CSS_PROP_ALIGN_ITEMS			= 0x073,
+	CSS_PROP_ALIGN_SELF			= 0x074,
+	CSS_PROP_FLEX_BASIS			= 0x075,
+	CSS_PROP_FLEX_DIRECTION			= 0x076,
+	CSS_PROP_FLEX_GROW			= 0x077,
+	CSS_PROP_FLEX_SHRINK			= 0x078,
+	CSS_PROP_FLEX_WRAP			= 0x079,
+	CSS_PROP_JUSTIFY_CONTENT		= 0x07a,
+	CSS_PROP_ORDER				= 0x07b,
 
 	CSS_N_PROPERTIES
 };
 
+enum css_align_content_e {
+	CSS_ALIGN_CONTENT_INHERIT		= 0x0,
+	CSS_ALIGN_CONTENT_STRETCH		= 0x1,
+	CSS_ALIGN_CONTENT_FLEX_START		= 0x2,
+	CSS_ALIGN_CONTENT_FLEX_END		= 0x3,
+	CSS_ALIGN_CONTENT_CENTER		= 0x4,
+	CSS_ALIGN_CONTENT_SPACE_BETWEEN		= 0x5,
+	CSS_ALIGN_CONTENT_SPACE_AROUND		= 0x6,
+	CSS_ALIGN_CONTENT_SPACE_EVENLY		= 0x7
+};
+
+enum css_align_items_e {
+	CSS_ALIGN_ITEMS_INHERIT			= 0x0,
+	CSS_ALIGN_ITEMS_STRETCH			= 0x1,
+	CSS_ALIGN_ITEMS_FLEX_START		= 0x2,
+	CSS_ALIGN_ITEMS_FLEX_END		= 0x3,
+	CSS_ALIGN_ITEMS_CENTER			= 0x4,
+	CSS_ALIGN_ITEMS_BASELINE		= 0x5
+};
+
+enum css_align_self_e {
+	CSS_ALIGN_SELF_INHERIT			= 0x0,
+	CSS_ALIGN_SELF_STRETCH			= 0x1,
+	CSS_ALIGN_SELF_FLEX_START		= 0x2,
+	CSS_ALIGN_SELF_FLEX_END			= 0x3,
+	CSS_ALIGN_SELF_CENTER			= 0x4,
+	CSS_ALIGN_SELF_BASELINE			= 0x5,
+	CSS_ALIGN_SELF_AUTO			= 0x6
+};
 
 enum css_background_attachment_e {
 	CSS_BACKGROUND_ATTACHMENT_INHERIT	= 0x0,
@@ -208,6 +249,12 @@ enum css_bottom_e {
 	CSS_BOTTOM_AUTO				= 0x2
 };
 
+enum css_box_sizing_e {
+	CSS_BOX_SIZING_INHERIT			= 0x0,
+	CSS_BOX_SIZING_CONTENT_BOX		= 0x1,
+	CSS_BOX_SIZING_BORDER_BOX		= 0x2
+};
+
 enum css_break_after_e {
 	CSS_BREAK_AFTER_INHERIT			= 0x0,
 	CSS_BREAK_AFTER_AUTO			= 0x1,
@@ -219,7 +266,7 @@ enum css_break_after_e {
 	CSS_BREAK_AFTER_COLUMN			= 0x7,
 	CSS_BREAK_AFTER_AVOID_PAGE		= 0x8,
 	CSS_BREAK_AFTER_AVOID_COLUMN		= 0x9
-};	
+};
 
 enum css_break_before_e {
 	CSS_BREAK_BEFORE_INHERIT		= CSS_BREAK_AFTER_INHERIT,
@@ -281,8 +328,8 @@ enum css_column_fill_e {
 
 enum css_column_gap_e {
 	CSS_COLUMN_GAP_INHERIT			= 0x0,
-	CSS_COLUMN_GAP_NORMAL			= 0x1,
-	CSS_COLUMN_GAP_SET			= 0x2
+	CSS_COLUMN_GAP_SET			= 0x1,
+	CSS_COLUMN_GAP_NORMAL			= 0x2
 };
 
 enum css_column_rule_color_e {
@@ -294,6 +341,7 @@ enum css_column_rule_color_e {
 enum css_column_rule_style_e {
 	CSS_COLUMN_RULE_STYLE_INHERIT		= CSS_BORDER_STYLE_INHERIT,
 	CSS_COLUMN_RULE_STYLE_NONE		= CSS_BORDER_STYLE_NONE,
+	CSS_COLUMN_RULE_STYLE_HIDDEN		= CSS_BORDER_STYLE_HIDDEN,
 	CSS_COLUMN_RULE_STYLE_DOTTED		= CSS_BORDER_STYLE_DOTTED,
 	CSS_COLUMN_RULE_STYLE_DASHED		= CSS_BORDER_STYLE_DASHED,
 	CSS_COLUMN_RULE_STYLE_SOLID		= CSS_BORDER_STYLE_SOLID,
@@ -320,8 +368,8 @@ enum css_column_span_e {
 
 enum css_column_width_e {
 	CSS_COLUMN_WIDTH_INHERIT		= 0x0,
-	CSS_COLUMN_WIDTH_AUTO			= 0x1,
-	CSS_COLUMN_WIDTH_SET			= 0x2
+	CSS_COLUMN_WIDTH_SET			= 0x1,
+	CSS_COLUMN_WIDTH_AUTO			= 0x2
 };
 
 enum css_content_e {
@@ -390,7 +438,9 @@ enum css_display_e {
 	CSS_DISPLAY_TABLE_COLUMN		= 0x0d,
 	CSS_DISPLAY_TABLE_CELL			= 0x0e,
 	CSS_DISPLAY_TABLE_CAPTION		= 0x0f,
-	CSS_DISPLAY_NONE			= 0x10
+	CSS_DISPLAY_NONE			= 0x10,
+	CSS_DISPLAY_FLEX			= 0x11,
+	CSS_DISPLAY_INLINE_FLEX			= 0x12
 };
 
 enum css_empty_cells_e {
@@ -399,6 +449,38 @@ enum css_empty_cells_e {
 	CSS_EMPTY_CELLS_HIDE			= 0x2
 };
 
+enum css_flex_basis_e {
+	CSS_FLEX_BASIS_INHERIT			= 0x0,
+	CSS_FLEX_BASIS_SET			= 0x1,
+	CSS_FLEX_BASIS_AUTO			= 0x2,
+	CSS_FLEX_BASIS_CONTENT			= 0x3
+};
+
+enum css_flex_direction_e {
+	CSS_FLEX_DIRECTION_INHERIT		= 0x0,
+	CSS_FLEX_DIRECTION_ROW			= 0x1,
+	CSS_FLEX_DIRECTION_ROW_REVERSE		= 0x2,
+	CSS_FLEX_DIRECTION_COLUMN		= 0x3,
+	CSS_FLEX_DIRECTION_COLUMN_REVERSE	= 0x4
+};
+
+enum css_flex_grow_e {
+	CSS_FLEX_GROW_INHERIT			= 0x0,
+	CSS_FLEX_GROW_SET			= 0x1
+};
+
+enum css_flex_shrink_e {
+	CSS_FLEX_SHRINK_INHERIT			= 0x0,
+	CSS_FLEX_SHRINK_SET			= 0x1
+};
+
+enum css_flex_wrap_e {
+	CSS_FLEX_WRAP_INHERIT			= 0x0,
+	CSS_FLEX_WRAP_NOWRAP			= 0x1,
+	CSS_FLEX_WRAP_WRAP			= 0x2,
+	CSS_FLEX_WRAP_WRAP_REVERSE		= 0x3
+};
+
 enum css_float_e {
 	CSS_FLOAT_INHERIT			= 0x0,
 	CSS_FLOAT_LEFT				= 0x1,
@@ -466,6 +548,16 @@ enum css_height_e {
 	CSS_HEIGHT_AUTO				= 0x2
 };
 
+enum css_justify_content_e {
+	CSS_JUSTIFY_CONTENT_INHERIT		= 0x0,
+	CSS_JUSTIFY_CONTENT_FLEX_START		= 0x1,
+	CSS_JUSTIFY_CONTENT_FLEX_END		= 0x2,
+	CSS_JUSTIFY_CONTENT_CENTER		= 0x3,
+	CSS_JUSTIFY_CONTENT_SPACE_BETWEEN	= 0x4,
+	CSS_JUSTIFY_CONTENT_SPACE_AROUND	= 0x5,
+	CSS_JUSTIFY_CONTENT_SPACE_EVENLY	= 0x6
+};
+
 enum css_left_e {
 	CSS_LEFT_INHERIT			= 0x0,
 	CSS_LEFT_SET				= 0x1,
@@ -473,9 +565,9 @@ enum css_left_e {
 };
 
 enum css_letter_spacing_e {
-	CSS_LETTER_SPACING_INHERIT		= 0x0,
-	CSS_LETTER_SPACING_SET			= 0x1,
-	CSS_LETTER_SPACING_NORMAL		= 0x2
+	CSS_LETTER_SPACING_INHERIT		= CSS_COLUMN_GAP_INHERIT,
+	CSS_LETTER_SPACING_SET			= CSS_COLUMN_GAP_SET,
+	CSS_LETTER_SPACING_NORMAL		= CSS_COLUMN_GAP_NORMAL
 };
 
 enum css_line_height_e {
@@ -537,12 +629,14 @@ enum css_max_width_e {
 
 enum css_min_height_e {
 	CSS_MIN_HEIGHT_INHERIT			= 0x0,
-	CSS_MIN_HEIGHT_SET			= 0x1
+	CSS_MIN_HEIGHT_SET			= 0x1,
+	CSS_MIN_HEIGHT_AUTO			= 0x2
 };
 
 enum css_min_width_e {
 	CSS_MIN_WIDTH_INHERIT			= 0x0,
-	CSS_MIN_WIDTH_SET			= 0x1
+	CSS_MIN_WIDTH_SET			= 0x1,
+	CSS_MIN_WIDTH_AUTO			= 0x2
 };
 
 enum css_opacity_e {
@@ -550,6 +644,11 @@ enum css_opacity_e {
 	CSS_OPACITY_SET				= 0x1
 };
 
+enum css_order_e {
+	CSS_ORDER_INHERIT			= 0x0,
+	CSS_ORDER_SET				= 0x1
+};
+
 enum css_outline_color_e {
 	CSS_OUTLINE_COLOR_INHERIT		= CSS_BACKGROUND_COLOR_INHERIT,
 	CSS_OUTLINE_COLOR_COLOR			= CSS_BACKGROUND_COLOR_COLOR,
@@ -603,7 +702,7 @@ enum css_page_break_after_e {
 	CSS_PAGE_BREAK_AFTER_ALWAYS		= CSS_BREAK_AFTER_ALWAYS,
 	CSS_PAGE_BREAK_AFTER_LEFT		= CSS_BREAK_AFTER_LEFT,
 	CSS_PAGE_BREAK_AFTER_RIGHT		= CSS_BREAK_AFTER_RIGHT
-};	
+};
 
 enum css_page_break_before_e {
 	CSS_PAGE_BREAK_BEFORE_INHERIT		= CSS_BREAK_AFTER_INHERIT,
@@ -727,8 +826,8 @@ enum css_white_space_e {
 enum css_widows_e {
 	CSS_WIDOWS_INHERIT			= 0x0,
 	CSS_WIDOWS_SET				= 0x1
-};	
-	
+};
+
 enum css_width_e {
 	CSS_WIDTH_INHERIT			= 0x0,
 	CSS_WIDTH_SET				= 0x1,
@@ -736,9 +835,9 @@ enum css_width_e {
 };
 
 enum css_word_spacing_e {
-	CSS_WORD_SPACING_INHERIT		= 0x0,
-	CSS_WORD_SPACING_SET			= 0x1,
-	CSS_WORD_SPACING_NORMAL			= 0x2
+	CSS_WORD_SPACING_INHERIT		= CSS_COLUMN_GAP_INHERIT,
+	CSS_WORD_SPACING_SET			= CSS_COLUMN_GAP_SET,
+	CSS_WORD_SPACING_NORMAL			= CSS_COLUMN_GAP_NORMAL
 };
 
 enum css_writing_mode_e {
