@@ -34,9 +34,9 @@ typedef enum css_pseudo_element {
  */
 typedef struct css_select_results {
 	/**
-	 * Array of pointers to computed styles, 
+	 * Array of pointers to computed styles,
 	 * indexed by css_pseudo_element. If there
-	 * was no styling for a given pseudo element, 
+	 * was no styling for a given pseudo element,
 	 * then no computed style will be created and
 	 * the corresponding pointer will be set to NULL
 	 */
@@ -117,8 +117,8 @@ typedef struct css_select_handler {
 	css_error (*node_is_lang)(void *pw, void *node,
 			lwc_string *lang, bool *match);
 
-	css_error (*node_presentational_hint)(void *pw, void *node, 
-			uint32_t property, css_hint *hint);
+	css_error (*node_presentational_hint)(void *pw, void *node,
+			uint32_t *nhints, css_hint **hints);
 
 	css_error (*ua_default_for_property)(void *pw, uint32_t property,
 			css_hint *hint);
@@ -157,7 +157,7 @@ typedef struct css_select_handler {
  */
 typedef struct css_select_font_faces_results {
 	/**
-	 * Array of pointers to computed font faces. 
+	 * Array of pointers to computed font faces.
 	 */
 	css_font_face **font_faces;
 	uint32_t n_font_faces;
@@ -204,12 +204,12 @@ css_error css_libcss_node_data_handler(css_select_handler *handler,
 css_error css_select_ctx_create(css_select_ctx **result);
 css_error css_select_ctx_destroy(css_select_ctx *ctx);
 
-css_error css_select_ctx_append_sheet(css_select_ctx *ctx, 
-		const css_stylesheet *sheet, 
-		css_origin origin, uint64_t media);
+css_error css_select_ctx_append_sheet(css_select_ctx *ctx,
+		const css_stylesheet *sheet,
+		css_origin origin, const char *media);
 css_error css_select_ctx_insert_sheet(css_select_ctx *ctx,
 		const css_stylesheet *sheet, uint32_t index,
-		css_origin origin, uint64_t media);
+		css_origin origin, const char *media);
 css_error css_select_ctx_remove_sheet(css_select_ctx *ctx,
 		const css_stylesheet *sheet);
 
@@ -217,17 +217,20 @@ css_error css_select_ctx_count_sheets(css_select_ctx *ctx, uint32_t *count);
 css_error css_select_ctx_get_sheet(css_select_ctx *ctx, uint32_t index,
 		const css_stylesheet **sheet);
 
+css_error css_select_default_style(css_select_ctx *ctx,
+		css_select_handler *handler, void *pw,
+		css_computed_style **style);
 css_error css_select_style(css_select_ctx *ctx, void *node,
-		uint64_t media, const css_stylesheet *inline_style,
+		const css_media *media, const css_stylesheet *inline_style,
 		css_select_handler *handler, void *pw,
 		css_select_results **result);
-css_error css_select_results_destroy(css_select_results *results);    
+css_error css_select_results_destroy(css_select_results *results);
 
 css_error css_select_font_faces(css_select_ctx *ctx,
-		uint64_t media, lwc_string *font_family,
+		const css_media *media, lwc_string *font_family,
 		css_select_font_faces_results **result);
 css_error css_select_font_faces_results_destroy(
-		css_select_font_faces_results *results);	
+		css_select_font_faces_results *results);
 
 #ifdef __cplusplus
 }
